@@ -1,7 +1,7 @@
 package Module::FatPack;
 
-our $DATE = '2015-06-11'; # DATE
-our $VERSION = '0.01'; # VERSION
+our $DATE = '2015-06-12'; # DATE
+our $VERSION = '0.02'; # VERSION
 
 use 5.010001;
 use strict;
@@ -29,8 +29,8 @@ a file or string.
 
 _
     args_rels => {
-        choose_one => ['module_names', 'module_srcs'],
-        'dep_one&' => [
+        req_one => ['module_names', 'module_srcs'],
+        'dep_any&' => [
             [stripper_maintain_linum => ['stripper']],
             [stripper_ws             => ['stripper']],
             [stripper_comment        => ['stripper']],
@@ -43,6 +43,9 @@ _
             summary => 'Module names to search',
             schema  => ['array*', of=>['str*', match=>$mod_re], min_len=>1],
             tags => ['category:input'],
+            pos => 0,
+            greedy => 1,
+            'x.schema.entity' => 'modulename',
         },
         module_srcs => {
             summary => 'Module source codes',
@@ -54,18 +57,25 @@ _
             tags => ['category:input'],
         },
         output => {
-            schema => 'str*',
             summary => 'Output filename',
+            schema => 'str*',
             cmdline_aliases => {o=>{}},
             tags => ['category:output'],
+            'x.schema.entity' => 'filename',
         },
         overwrite => {
-            schema => [bool => default => 0],
             summary => 'Whether to overwrite output if previously exists',
             'summary.alt.bool.yes' => 'Overwrite output if previously exists',
+            schema => [bool => default => 0],
             tags => ['category:output'],
         },
 
+        assume_strict => {
+            summary => 'Assume code runs under stricture',
+            schema => 'bool',
+            default => 1,
+        },
+
         stripper => {
             summary => 'Whether to strip included modules using Perl::Stripper',
             'summary.alt.bool.yes' => 'Strip included modules using Perl::Stripper',
@@ -189,7 +199,12 @@ sub fatpack_modules {
 s/^  //mg for values %fatpacked;
 
 my $class = 'FatPacked::'.(0+\%fatpacked);
+_
+
+    push @res, <<'_' if $args{assume_strict} // 1;
 no strict 'refs';
+_
+    push @res, <<'_';
 *{"${class}::files"} = sub { keys %{$_[0]} };
 
 if ($] < 5.008) {
@@ -250,7 +265,7 @@ Module::FatPack - Generate source code that contains fatpacked modules
 
 =head1 VERSION
 
-This document describes version 0.01 of Module::FatPack (from Perl distribution Module-FatPack), released on 2015-06-11.
+This document describes version 0.02 of Module::FatPack (from Perl distribution Module-FatPack), released on 2015-06-12.
 
 =head1 SEE ALSO
 
@@ -273,6 +288,10 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
+=item * B<assume_strict> => I<bool> (default: 1)
+
+Assume code runs under stricture.
+
 =item * B<module_names> => I<array[str]>
 
 Module names to search.
